#
# spec file for package perl-DBD-Pg
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name DBD-Pg
Name:           perl-DBD-Pg
Version:        3.18.0
Release:        1.2
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        DBI PostgreSQL interface
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/T/TU/TURNSTEP/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(DBI) >= 1.614
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(version)
Requires:       perl(DBI) >= 1.614
Requires:       perl(version)
Recommends:     perl(Module::Signature) >= 0.50
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  openssl-devel
BuildRequires:  postgresql-devel >= 8.1
%if 0%{?suse_version} >= 1550 || 0%{?sle_version} >= 150200
BuildRequires:  postgresql-server-devel
%endif
# For the Testsuite
BuildRequires:  postgresql-server
# MANUAL END

%description
DBD::Pg is a Perl module that works with the DBI module to provide access
to PostgreSQL databases.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
HARNESS_TIMER=1 HARNESS_VERBOSE=1 make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING.md README README.dev README.win32 TODO win32.mak

%changelog
* Thu Dec  7 2023 Tina Müller <timueller+perl@suse.de>
- updated to 3.18.0
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.18.0 (released December 6, 2023)
  - Support new PQclosePrepared function, added in Postgres 17
    [Greg Sabino Mullane]
  - Better docs about ping always returning a value
    (Github issue #121)
* Thu Aug 24 2023 Tina Müller <timueller+perl@suse.de>
- updated to 3.17.0
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.17.0  (released August 23, 2023)
  - New database handle attribute pg_skip_deallocate
    Prevents any deallocation of automatically prepared
    statements to support new pgBouncer feature
    [Greg Sabino Mullane]
  - Fix to handle escaped quotes in connection string
    [Dagfinn Ilmari Mannsåker]
  - Return number of affected rows from a MERGE command
    [Greg Sabino Mullane]
    (Github issue #118)
  - Add support for Github CI actions
    [Gábor Szabó]
    (Github pull request #115)
  - Remove undocumented internal-only pg_pid_number attribute
    [Greg Sabino Mullane]
    (Github issue #102)
  - Small warning in docs about PG_CHAR
    [Greg Sabino Mullane]
    (Github issue #103)
* Wed Apr  5 2023 Tina Müller <timueller+perl@suse.de>
- updated to 3.16.3
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.16.3  (released April 4, 2023)
* Fri Mar 10 2023 Tina Müller <timueller+perl@suse.de>
- updated to 3.16.1
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.16.1 (released March 5, 2023)
  - Add new attribute "pg_int8_as_string", for backwards compatibility.
    [Alexander Gorlov]
    (Github pull request #100)
  - Add a META.json file; rename META.yml to META.yaml
  - Fix 03smethod.t $sth->last_insert_id skip count for DBI < 1.642
    [Dagfinn Ilmari Mannsåker]
    (Github issue #99)
  - Documentation improvements for service files
    [Erik Rijkers]
* Tue Aug  9 2022 Tina Müller <timueller+perl@suse.de>
- updated to 3.16.0
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.16.0 (August 8, 2022)
  - Automatically use 64-bit versions of large object functions when available
    [Dagfinn Ilmari Mannsåker, David Christensen]
  - Set UTF8 flag as needed for error messages
    [Github user olafgw]
    (Github issue #97)
  - In tests, do not assume what the default transaction isolation level will be
    [Rene Schickbauer]
    (Github issue #94)
  - Make tests smarter about detecting pg_ctl results in different locales
    [Greg Sabino Mullane]
    (Github issue #95)
* Tue Feb 15 2022 Tina Müller <timueller+perl@suse.de>
- updated to 3.15.1
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
* Sat May 22 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.15.0
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.15.0 (released May 21, 2021)
  - Adjust tests for the fact that reltuples can be -1 in Postgres
    version 13 and later. This is mostly reflected in the CARDINALITY
    column for $dbh->statistics_info.
    [Greg Sabino Mullane]
  - Correctly pull back pg_async status from statement handle.
    Previously, $dbh->{pg_async} would return undef.
    [Greg Sabino Mullane]
    (RT ticket #136553)
  - Remove the experimental 'fulltest' Makefile target.
    [Greg Sabino Mullane]
    (RT ticket #136567)
* Fri Aug 14 2020 Tina Müller <timueller+perl@suse.de>
- updated to 3.14.2
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
* Mon Jul 20 2020 Tina Müller <timueller+perl@suse.de>
- updated to 3.14.0
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.14.0  (released Jul 19, 2020)
  - The $dbh->primary_key_info and $dbh->foreign_key_info methods will now always return
    a statement handle, even with no matches. Previously, they returned undef directly.
    Callers can check if the returned handle contains any rows.
    [Greg Sabino Mullane]
  - The $dbh->tables method will always return a list, even if it is empty.
    [Greg Sabino Mullane]
  - Add pg_lo_tell64, pg_lo_seek64, and pg_lo_truncate64, for anyone dealing
    with really, really, really large 'large objects'. Requires Postgres 9.3 or better.
    [Greg Sabino Mullane]
    (RT ticket #123561)
  - Allow test to run again when using a non-superuser to connect
    [Greg Sabino Mullane]
    (RT ticket #132865)
  - Adjust tests to force loading proper version of DBD::Pg every time.
    [Greg Sabino Mullane]
  - Removed the long-deprecated _pg_use_catalog method.
    [Greg Sabino Mullane]
  - Many improvements and changes to the test suite.
    [Greg Sabino Mullane]
* Thu Jun 18 2020 Tina Müller <timueller+perl@suse.de>
- updated to 3.13.0
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.13.0  (released June 17, 2020)
  - Redo the "last_result" internals in dbdimp.c, which
    fixes a memory leak.
    [Greg Sabino Mullane]
    (RT ticket #132812)
  - Fix regression in Perl length() for returned query results
    [Jon Jensen]
    (Github issue #72)
  - Make $sth->finish() do a little less. Notably, even
    after calling finish(), pg_error_field will still work
    on the last action performed.
    [Greg Sabino Mullane]
  - Tweak tests so Windows boxes pass
    [Greg Sabino Mullane]
* Wed Jun 10 2020 Tina Müller <tina.mueller@suse.com>
- Run tests in verbose mode. Fixes mysterious failure of t/09arrays.t
  An issue exists: https://rt.cpan.org/Ticket/Display.html?id=132799
* Sat Jun  6 2020 Tina Müller <timueller+perl@suse.de>
- updated to 3.12.3
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.12.3  (released June 5, 2020)
  - Prevent DBI from flipping AutoCommit to 'on' after a failed commit
    [Greg Sabino Mullane]
    (Github issue #57)
  Version 3.12.2  (released June 4, 2020)
  - Revert overly aggressive testing shortcut as it can cause installs to fail
    [Greg Sabino Mullane, with apologies]
* Thu Jun  4 2020 Tina Müller <timueller+perl@suse.de>
- updated to 3.12.1
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.12.1  (released June 3, 2020)
  - Remove test that assumed '(12,34)' is an invalid entry for type "circle",
    as the Postgres source code changed this behavior on April 7, 2020
    [Greg Sabino Mullane]
    (RT ticket #132740)
* Fri May  8 2020 Tina Müller <timueller+perl@suse.de>
  updated to 3.12.0
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.12.0  (released May 7, 2020)
  - Add CONTRIBUTING.md file
  - Return the table info row last in statistics_info.
    This fixes statistics_info on pre-8.3 servers.
    [Dagfinn Ilmari Mannsåker]
  - Fix ASC_OR_DESC field in statistics_info
    [Dagfinn Ilmari Mannsåker]
  - Indicate NULL ordering in statistics_info
    [Dagfinn Ilmari Mannsåker]
* Wed Apr 29 2020 Tina Müller <timueller+perl@suse.de>
  updated to 3.11.1
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.11.1  (released April 28, 2020)
  - Adjust Makefile to fix failing 'fulltest' target on BSD systems
    [Slaven Rezić]
    (RT ticket #132412)
  Version 3.11.0  (released April 23, 2020)
  - Indicate non-key index columns (INCLUDE) in statistics_info
    [Dagfinn Ilmari Mannsåker]
  - Return an empty result set instead of undef from statistics_info
    when the requested table doesn't exist and $unique_only is false.
    [Dagfinn Ilmari Mannsåker]
  - Fix segfault during st destroy
    [Gregory Oschwald]
    (Github pull request #66)
    (Github issue #57)
  - Improve testing for table_info()
    [Greg Sabino Mullane]
    (Github issue #67)
  - Improve UTF-8 wording in docs
    [Felipe Gasper]
    (Github pull request #65)
* Tue Mar 24 2020 Tina Müller <tina.mueller@suse.com>
- Fix BuildRequires in cpanspec.yml to match what's in the .spec
* Tue Mar 24 2020 <timueller+perl@suse.de>
- updated to 3.10.5
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Changes for the DBD::Pg module
* Thu Mar  5 2020 Max Lin <mlin@suse.com>
- Build requries postgresql-server-devel on Leap 15.2/SLE15 SP2
* Tue Feb  4 2020 <timueller+perl@suse.de>
- updated to 3.10.4
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.10.4  (released February 3, 2020)
  - Allow localtime from Time::Piece to be used directly as a bind value again.
    This applies to all "magical" arrays.
    [Greg Sabino Mullane]
    [Github issue #63]
  - Force tests to NOT run in parallel.
    [Greg Sabino Mullane]
    [RT #130834]
* Tue Jan 21 2020 <timueller+perl@suse.de>
- updated to 3.10.3
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.10.3  (released January 20, 2020)
    Set things cleared via PQclear to NULL as soon as possible, to remove race conditions.
    [Greg Sabino Mullane]
    [RT #131522]
  Version 3.10.2  (released January 17, 2020)
  - Adjust tests to pass on 32-bit machines
    [Greg Sabino Mullane]
    [RT #131482]
  Version 3.10.1  (released January 13, 2020)
  - Prevent double-free memory errors
    [Greg Sabino Mullane]
    [RT #130681]
  - Fix crash when pg_error_field is called
    [Greg Sabino Mullane]
    [RT #130721]
  - Update the list of Postgres reserved words in quote.c
* Wed Sep  4 2019 <timueller+perl@suse.de>
- updated to 3.10.0
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
* Tue Aug 20 2019 Stephan Kulow <coolo@suse.com>
- remove disable-attr.patch as longer needed
* Fri Aug 16 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.9.1
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.9.1, released August 15, 2019
    Bugfix for pg_error_field: make sure we do not feed null to newSVpv,
    handle older versions of Postgres better.
    [Greg Sabino Mullane]
* Wed Aug 14 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.9.0
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.9.0, released August 13, 2019
  - ShowErrorStatement works for "quickexec" do() calls
    [Dmitry Karasik]
    [RT #120268]
    [Github issue #44]
  - Add :pg_limits to add constants such as PG_MAX_SMALLINT
    [Greg Sabino Mullane]
    [Github issue #51]
  - Add $dbh->pg_error_field() function
    [Greg Sabino Mullane]
  - Fix failing tests due to incorrect 'initdb' check
    [Greg Sabino Mullane]
    [Github issue #54]
    [RT #130279]
* Tue Jul 16 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.8.1
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.8.1, released July 6, 2019
  - Fix encoding of SQL_VARBINARY type in $dbh->quote() function
    [Pali]
  - Fix E'' string escape handling on architectures with unsigned chars
    [Github issue #46]
  - Minor fix to allow DBD::Pg to connect to PGbouncer's internal 'pgbouncer' database.
    [Greg Sabino Mullane]
    [Github issue #47]
  - Fix so table_info test works on non-empty databases
    [Matt Buchanan]
    [CPAN ticket #127906]
* Fri Apr 26 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.8.0
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.8.0, released April 25, 2019
  - Increase minimum supported PostgreSQL version to 8.0
    [Dagfinn Ilmari Mannsåker]
  - Add support for foreign tables in table_info() and column_info()
    [Dagfinn Ilmari Mannsåker]
  - Return the current database name as TABLE_CAT in info methods
    [Dagfinn Ilmari Mannsåker]
  - Handle backslash-escaped quotes in E'' strings
    [Dagfinn Ilmari Mannsåker]
  - Fix typo in Makefile.PL
    [CPAN ticket #127097]
  - Fix parsing of PostgreSQL versions >= 10 on Debian/Ubuntu
    [Dagfinn Ilmari Mannsåker]
  - Fix client_min_messages=FATAL test when PostgreSQL caps it to ERROR
    [Dagfinn Ilmari Mannsåker]
    [CPAN ticket #128529]
  - Fix ->ping error detection on PostgreSQL 12
    [Dagfinn Ilmari Mannsåker]
  - Adjust tests for new pg_ctl output
    [Erik Rijkers    er at xs4all.nl]
    [CPAN ticket #128966]
  - Adjust tests for removal of WITH OIDS in PostgreSQL 12
    [Dagfinn Ilmari Mannsåker]
  - Fix support for PostgreSQL versions back to 8.0
    [Dagfinn Ilmari Mannsåker]
  - Remove usage of deprecated pg_attrdef.adsrc and pg_constraint.consrc columns
    [Dagfinn Ilmari Mannsåker]
  - Fix typo in pg_placeholder_colons example
    (Github issue #41)
  - Support GENERATED ... AS IDENTITY columns in last_insert_id()
    [Dagfinn Ilmari Mannsåker]
* Tue Feb 26 2019 Stephan Kulow <coolo@suse.com>
- apply disable-attr.patch to disable broken test:
  https://rt.cpan.org/Public/Bug/Display.html?id=128529
* Wed Feb 14 2018 coolo@suse.com
- updated to 3.7.4
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
* Mon Feb 12 2018 coolo@suse.com
- updated to 3.7.1
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.7.1  Released February 11, 2017 (git tag 3.7.1)
  - Fixed problem when using placeholders and escaped question marks, the recopied string
    was not terminated correctly.
    [Greg Sabino Mullane]
    (Github issue #33)
  - Make sure nulls in our self-generated arrays are not set as read-only in some Perls.
    [Greg Sabino Mullane]
    (CPAN ticket #107556)
  - If the server returns no error message, and an "unknown" code from libpq, supply a custom
    message mentioning client_min_messages may be to blame.
    [Greg Sabino Mullane]
    (CPAN ticket #109591)
  - Declare VERSION with 'our' in seldom-used Bundle module
    (CPAN ticket #123218)
* Fri Oct  6 2017 coolo@suse.com
- updated to 3.7.0
  see /usr/share/doc/packages/perl-DBD-Pg/Changes
  Version 3.7.0  Released September 24, 2017 (git tag 3.7.0)
  - If no placeholders, use PQexec instead of PQexecParams
    [Greg Sabino Mullane]
  - Fix running tests with non-UTF8 server_encoding
    [Dagfinn Ilmari Mannsåker]
    (Github issue #26)
  - Fix crash with missing client_encoding
    [David Christensen, reported by Marko Tiikkaja]
    (Github issue #29)
  - Fix crash with missing server_version
    [David Christensen]
  - Fix leak in ->state methods
    [Dagfinn Ilmari Mannsåker]
    (Github issue #30)
  - Add $sth->{pg_async_status} to determine async status of a statement handle.
    Values can be 0 (no async), 1 (async), or -1 (cancelled)
    [Greg Sabino Mullane, as requested by Dmytro Zagashev (ZDM)]
    (CPAN ticket #116172)
  Version 3.6.2  Released May 23, 2017 (git tag 3.6.2)
  - Remove errant debugging aid from test suite
  Version 3.6.1  Released May 22, 2017 (git tag 3.6.1)
  - Various fixes to support testing against Postgres 10beta
    [David Christensen]
  Version 3.6.0  Released April 17, 2017 (git tag 3.6.0)
  - Make sure we do not inadvertently modify the string passed to prepare() when
    doing the new backslash escape manipulation.
    [Greg Sabino Mullane]
    (CPAN ticket #114000)
  - Fix bug where $DBD::Pg::DBDPG_DEFAULT not picked up as a magic
    string first time it is used in a script.
    [Greg Sabino Mullane]
    (CPAN ticket #112309)
  - Fix UTF8 flag handling in pg_(get|put)copydata
    [Dagfinn Ilmari Mannsåker]
  - Fix UTF8 double-encoding with pg_enable_utf8 = 0
    [Serge Pushkin]
    (CPAN ticket #103137)
  - Fix bug in quote_name which would fail to quote in some circumstances
    (Github Issue #22)
  - Allow clean parsing of new Postgres X.Y version format
    [Erik Rijkers    er at xs4all.nl]
  - Add pg_canonical_ids() and pg_canonical_names(), which returns information
    about each column in the result set.
    [Warstone    warstone at list.ru]
    (CPAN ticket #106858)
  - Map SQL_NUMERIC to PG_NUMERIC (instead of PG_FLOAT8)
    [Alice Maz    alice at alizemaz.com]
    (CPAN ticket #120358)
  - Force real, float, and double precision into SvNVs
    [Greg Sabino Mullane]
    (CPAN ticket #113683 and other places)
  - Support for number of rows greater than an "int". Requires support for same
    from a future version of libpq before it will work completely.
    [Greg Sabino Mullane]
    (CPAN ticket #102444)
  - Fix skipped test counts in Win32 builds
    [Andy Grundman]
  - Allow tests to work against Postgres 8.4 by tweaking client_encoding calls.
    [Pavel Raiskup    praiskup at redhat.com]
    (CPAN ticket #116179)
  - Silence warnings in t/02attribs.t and t/04misc.t
    [Dagfinn Ilmari Mannsåker]
  - Support binary COPY format
    [Dagfinn Ilmari Mannsåker]
  - Ensure tests do not use $ENV{PGSERVICE} or $ENV{PGDATABASE}
    [Erik Rijkers]
  - Switched canonical repo to git://github.com/bucardo/dbdpg.git
* Wed Aug 30 2017 coolo@suse.com
- Just use postgresql-server everywhere and leave it up to prjconf,
  SLE12 has no 94 in maintenance anymore
* Sat Mar 18 2017 aj@ajaissle.de
- Fixed sle_version macro
- Removed %%clean section
* Tue Dec  8 2015 stephan.barth@suse.com
- update to version 3.5.3
  changes with 3.5.3:
  - Minor fix in the test file t/03dbmethod.t
  changes with 3.5.2:
  - Fix enum value ordering on Postgres servers 9.1 and greater
  - Return bigint values as plain integer values when they fit
  - Fix typo in sprintf for get_info() SQL_DATA_SOURCE_NAME
  - Set the repository in META.yml to github
* Wed Feb 18 2015 stephan.barth@suse.com
- Update to version 3.5.1 from 3.5.0
  Upstream changes:
  - Prevent core dump if the second argument to the quote() method
    is anything but a hashref
  - Better "support" for SQL_ASCII servers in the tests.
    Allow env var DBDPG_TEST_ALWAYS_ENV to force use of DBI_DSN and DBI_USER
    in tests.
  - Fix client_encoding detection on pre-9.1 servers
  - Fix operator existence check in tests on pre-8.3 servers
  - Documentation fix
  - Fix pg_switch_prepared database handle documentation
* Mon Jan 26 2015 stephan.barth@suse.com
- Update to version 3.5.0 from 3.4.1
  Upstream changes:
  - 3.5.0
  - Allow "placeholder escaping" by the use of a backslash directly before
    it (CPAN bug #101030)
  - Improve the workings of the ping() method (CPAN bug #100648)
  - Add get_info(9000) => 1 to indicate driver can escape placeholders.
  - In tests, force the client_encoding to UTF8, skip tests that involve
    characters not supported by the server_encoding
  - Fix memory leak when selecting from arrays
  - Make get_info much more efficient and slightly simpler
  - 3.4.2
  - Fix bug where single-quoted type arguments to the table_info()
    method were causing a SQL error. (CPAN bug #99144)
* Thu Aug 21 2014 stephan.barth@suse.com
- Update to version 3.4.1 from 3.4.0
  Change from upstream:
  - Allow '%%' again for the type in table_info() and thus tables()
    It's not documented or tested in DBI, but it used to work until
    DBD::Pg 3.4.0, and the change broke DBIx::Class::Schema::Loader, which
    uses type='%%'.
* Mon Aug 18 2014 stephan.barth@suse.com
- update to version 3.4.0 from 3.3.0
  Upstream changes:
  - Cleanup and improve table_info()
    table_info() type searching now supports TABLE, VIEW, SYSTEM TABLE,
    SYSTEM VIEW, and LOCAL TEMPORARY
    table_info() object searching fully supports the above types.
    table_info() object searching no longer ignores invalid types - a filter
    of 'NOSUCH' will return no rows, and 'NOSUCH,LOCAL TEMPORARY' will
    return only temp objects.
    tableinfo() type filters are strictly matched now ... previously a
    search for SYSTEM TABLE would have fetched plain TABLE objects.
    table_info() now treats temporary tables and temporary views as LOCAL
    TEMPORARY
  - Make sure column_info() and table_info() can handle materialized views.
* Mon Jun  2 2014 stephan.barth@suse.com
- update to version 3.3.0 from 3.2.1
  Upstream changes:
  - Major cleanup of UTF-8 support
  - Rewrite foreign_key_info to be just one query
  - Remove ODBC support from foreign_key_info
  - Remove use of dTHX in functions in quote.c and types.c
* Thu May 29 2014 stephan.barth@suse.com
- update to version 3.2.1 from 3.2.0
  Changes from upstream:
  - Stricter testing for array slices: disallow number-colon-number from
    being parsed as a placeholder.
    [Greg Sabino Mullane] (CPAN bug #95713)
  - Fix for small leak with AutoInactiveDestroy
    [David Dick] (CPAN bug #95505)
  - Adjust test regex to fix failing t/01_connect.t on some platforms
    [Greg Sabino Mullane]
  - Further tweaks to get PGINITDB working for test suite.
    [Nicholas Clark]
* Fri May 16 2014 stephan.barth@suse.com
- update to version 3.2.0 from 3.1.1
  Changes from upstream:
  - Add new attribute pg_placeholder_nocolons to turn off all parsing of
    colons into placeholders.
    [Graham Ollis] (CPAN bug #95173)
  - Fix incorrect skip count for HandleSetErr
    [Greg Sabino Mullane] (CPAN bug #94841)
  - Don't attempt to use the POSIX signalling stuff if the OS is Win
    [Greg Sabino Mullane] (CPAN bug ##94841)
  - Fix missing check for PGINITDB in the test suite.
    [Nicholas Clark]
* Tue Apr  8 2014 stephan.barth@suse.com
- update to version 3.1.1 from 3.0.0
  Changes from upstream:
  Version 3.1.1  Released April 6, 2014
  - Minor adjustments so tests pass in varying locales.
  Version 3.1.0  Released April 4, 2014
  - Make sure UTF-8 enabled notifications are handled correctly
    [Greg Sabino Mullane]
  - Allow "WITH" and "VALUES" as valid words starting a DML statement
    [Greg Sabino Mullane] (CPAN bug #92724)
* Wed Mar 26 2014 stephan.barth@suse.com
- update from version 2.19.3 to 3.0.0
  These are the most important changes from upstream:
  - Major change in UTF-8 handling
  - Better handling of libpq errors to return SQLSTATE 08000
  - Add support for AutoInactiveDestroy
  and many bugfixes. See the Changes file for a full list of changes.
* Tue Jan 21 2014 kpetsch@suse.com
-Added BuildRequires postgresql-server to provide initdb for the
  testsuite.
* Fri May  3 2013 darin@darins.net
- update to 2.19.3
  - Fix bug in pg_st_split_statement causing segfaults
    (CPAN bug #79035)
  - See Changes for 2.19.0 - 2.19.2 changes
* Tue Nov 29 2011 coolo@suse.com
- update to 2.18.1
  - Fix LANG testing issue [GSM] (CPAN bug #56705)
  - Fix bug when async commands issued immediately after a COPY.
    [GSM] (CPAN bug #68041)
* Fri Apr  8 2011 chris@computersalat.de
- fix deps
  o add openssl-devel
- fix build
  o build with -lssl
- bzip source
- add testme.tmp.pl to doc
* Thu Mar 31 2011 coolo@novell.com
- update to 2.18.0
  - Thanks to 123people.com for sponsoring work on this release [GSM]
  - Fix memory leak when binding arrays [GSM] (CPAN bug #65734)
  - Fix memory leak with ParamValues. [Martin J. Evans] (CPAN bug #60863)
  - New cancel() method per DBI spec. [Eric Simon] (CPAN bug #63516)
  - Fix memory leak in handle_old_async (missing PQclear)
  [Rainer Weikusat] (CPAN bug #63408)
  - Fix memory leak in pg_db_cancel (missing PQclear)
  [Rainer Weikusat] (CPAN bug #63441)
  - Mark pg_getcopydata strings as UTF8 as needed (CPAN bug #66006)
  - Function dequote_bytea returning void should not try to return something
  [Dagobert Michelsen] (CPAN bug #63497)
  - Fix the number of tests to skip in t/01connect.t when the $DBI_DSN
  environment variable lacks a database specification. [David E. Wheeler]
  - Fix algorithm for skipping tests in t/06bytea.t when running on a version
  of PostgreSQL lower than 9.0. [David E. Wheeler]
  - Small tweaks to get tests working when compiled against Postgres 7.4
  (CPAN bug #61713) [GSM]
  - Fix failing test when run as non-superuser [GSM] (CPAN bug #61534)
* Thu Dec  2 2010 chris@computersalat.de
- update to 2.17.2
  - Support dequoting of hex bytea format for 9.0.
    [Dagfinn Ilmari MannsÃ¥ker] (CPAN bug #60200).
  - Don't PQclear on execute() if there is an active async query
    [rweikusat at mssgmbh.com] (CPAN bug #58376)
  - Allow data_sources() to accept any case-variant of 'dbi:Pg' (CPAN bug #61574)
  - Fix failing test in t/04misc.t on Perl 5.12. [Eric Simon]
  - Fix for some 7.4 failing tests [Dagfinn Ilmari MannsÃ¥ker]
  - Return bare instead of undef in test connections (CPAN bug #61574)
- recreated by cpanspec 1.78
- removed Authors
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Apr 21 2010 chris@computersalat.de
- update to 2.17.1
  - Only use lo_import_with_oid if Postgres libraries are 8.4 or better
    [GSM] (CPAN bug #56363)
- added Buildi-/Req perl(version)
- fix deps for postgresql-devel >= 7.4
* Wed Apr  7 2010 chris@computersalat.de
- update to 2.17.0
  - Do not automatically ROLLBACK on a failed pg_cancel [GSM]
    (CPAN bug #55188)
  - Added support for new lo_import_with_oid function.
    [GSM] (CPAN bug #53835)
  - Don't limit stored user name to \w in tests [GSM]
    (CPAN bug #54372)
  - Allow tests to support versions back to Postgres 7.4 [GSM]
- TestSuite broken for postgresql < 8.4
  o undefined symbol: lo_import_with_oid
  o BUG opened
    https://rt.cpan.org/Public/Bug/Display.html?id=56363
* Tue Apr  6 2010 chris@computersalat.de
- update to 2.16.1
  - Output error messages in UTF-8 as needed. Reported biy
    Michael Hofmann. [GSM] (CPAN bug #53854)
- 2.16.0 Released December 17, 2009
  - Put in a test for high-bit characters in bytea handling.
  [Bryce Nesbitt] (see also CPAN bug #39390)
  - Better SQLSTATE code on connection failure (CPAN bug #52863)
  [Chris Travers with help from Andrew Gierth]
  - Fixed POD escapes (CPAN bug #51856) [FWIE@cpan.org]
- cleanup spec
  o sort TAGS
  o upated Summary
  o macros
  o fixed deps
- added perl-macros
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Wed Aug 12 2009 max@suse.de
- New version: 2.15.1.
- http://cpansearch.perl.org/src/TURNSTEP/DBD-Pg-2.15.1/Changes
* Thu Sep 11 2008 max@suse.de
- New version: 2.10.3:
  * Add the 'DBD' trace setting to output only non-DBI trace
    messages, and allow 'dbd_verbose' as a connection attribute
    for the same effect.
  * Allow multi-statement do() calls with parameters to work if
    pg_server_prepare is set to 0
  * Add support for database handle attribute "ReadOnly".
  * Added in payload strings for LISTEN/NOTIFY in 8.4.
  * Plus more bug fixes and improvements to the test suite and
    documentation.
* Tue Apr 22 2008 max@suse.de
- Fixed file list.
* Thu Apr 17 2008 max@suse.de
- New version: 2.6.0. Changes include:
  * Various performance improvements.
  * Add Bundle::DBD::Pg
  * Fix memory leaks in dbdimp.c
  * Fix strlen problems in dbdimp.c
  * Overhaul COPY functions
  * Add support for arrays
  * Add support for asynchronous queries
- See /usr/share/doc/packages/perl-DBD-Pg/Changes for details.
* Fri May 19 2006 max@suse.de
- New version: 1.49:
  * Added support for geometric types.
  * Various bugfixes.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 max@suse.de
- New version: 1.42 (bug #128183).
* Sat Feb 28 2004 ro@suse.de
- fix requirement for /usr/local
- fix "control reaches end of non-void function"
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Jul 21 2003 max@suse.de
- new version: 1.22
- Fix build for perl-5.8.1.
* Mon Jun 30 2003 ro@suse.de
- remove traces of buildroot from installed files
* Sun Jun 22 2003 coolo@suse.de
- package directories
* Wed Feb  5 2003 ro@suse.de
- updated neededforbuild
* Wed Jul  3 2002 max@suse.de
- New package perl-DBD-Pg version 1.13.
- A database driver for perl-DBI and PostgreSQL.
